
/* A conversion table between ASCII and SMS 7bit character set

 Note that not all characters can be translated exactly as they are
 between ASCII and GSM character sets.
 The following conversion table is for example only and can be modified
 when designing the actual application. This example assumes the use of
 US ASCII character set (codepage) activated in the PC
	Ref. GSM 03.38
 Only the default alphabet is implemented in this example.
 */

#define NULL	1
#define __NFILE_H	1



#define SMS7BIT "@$\n\r_𫒑 !\"#$%&'()*+,-./0123456789:;<=>?\
ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz"
// Various TPDU field definitions GSM 03.40

// Definitions for the first octet in TPDU

// TP-Message-Type-Indicator(TP-MTI)
#define MTI_SMS_DELIVER			0
#define MTI_SMS_DELIVER_REPORT		0
#define MTI_SMS_STATUS_REPORT		2
#define MTI_SMS_COMMAND			2
#define MTI_SMS_SUBMIT			1
#define MTI_SMS_SUBMIT_REPORT		1
#define MTI_SMS_RESERVED		4

// TP-Reply-Path request  (TP-RP)
#define TP_RP   	 0x80

// TP-User-Data-HeaderIndicator (TP-UDHI)
#define TP_UDHI	 0x40

// TP-Status-Report-Request (TP-SRR)
#define MTI_SRR    0x20

// TP-Status-Report-Indicator (TP-SRI)
#define TP_SRI    0x20

// TP-Validity-Period-Format (TP-VPF)
#define TP_VPF_NOT_PRESENT		0
#define TP_VPF_RELATIVE			0x10
#define TP_VPF_RESERVED			0x08
#define TP_VPF_ABSOLUTE			0x18

// TP-Reject-Duplicates  (TP-RD)
#define TP_RD									0x04

// TP More-Messages-To-Send  (TP-MMS)

#define TP_MMS				0x02

// Definitions for the Type Of Address field

// Type of Number sub-field
#define DA_TON_UNKNOWN          	0x80
#define DA_TON_INTERNATIONAL      	0x90
#define DA_TON_NATIONAL           	0xA0
#define DA_TON_NETWORK_SPECIFIC   	0xB0
#define DA_TON_SUBSCRIBER         	0xC0
#define DA_TON_ALPHANUMERIC       	0xD0
#define DA_TON_ABBREVIATED        	0xE0
#define DA_TON_RESERVED           	0xF0

// Numbering Plan Identification sub-field
#define DA_NPI_UNKNOWN            	0x0
#define DA_NPI_ISDN               	0x1
#define DA_NPI_DATA               	0x3
#define DA_NPI_TELEX              	0x4
#define DA_NPI_NATIONAL           	0x8
#define DA_NPI_PRIVATE            	0x9
#define DA_NPI_ERMES              	0xA
#define DA_NPI_RESERVED           	0xF

// Definitions for the TP_PID field
#define PID_IMPLICIT              	0x00
#define PID_TELEX                 	0x01
#define PID_TELEFAX_3             	0x02
#define PID_TELEFAX_4             	0x03
#define PID_VOICE                 	0x04
#define PID_ERMES                 	0x05
#define PID_NAT_PAGING            	0x06
#define PID_VIDEOTEX              	0x07
#define PID_TELETEX_PSPDN         	0x08
#define PID_TELETEX_CSPDN         	0x09
#define PID_TELETEX_PSTN          	0x0A
#define PID_TELETEX_ISDN          	0x0B
#define PID_UCI                   	0x0C
#define PID_MSGHAND               	0x10
#define PID_MSGHAND_X400          	0x11
#define PID_EMAIL                 	0x12
#define PID_MSGHAND               	0x10
#define PID_GSM                   	0x1F
#define PID_INTERWORKING          	0x20

#define STAT_RCVD_UNREAD         	0
#define STAT_RCVD_READ            	1
#define STAT_STORED_UNSENT       	2
#define STAT_STORED_SENT         	3
#define STAT_DELETED              	-1

// Structure definition for incoming SMS
typedef struct{
	int loc;          	// Memory index
	int stat;         	// Message status
	char tpdu_str[315];    	// TPDU string from the Module
	int length;       	// Length of the TPDU part
	char sca[23];     	// SCA address
	} sms_rcvd;


// Structure definitions for PDU types
// according to GSM 03.40 (only 2 of 6 are defined in this sample).

typedef struct {  // Outgoing TPDU
	 unsigned char tp_mt;	      	// The first octet (MTI, etc.)
	 unsigned char tp_mr;       	// Message Reference
	 unsigned char tp_da[12];	// Destination Address (max 12 octets)
	 unsigned char tp_pid;      	// Protocol ID
	 unsigned char tp_dcs;		// Data Coding Scheme
	 unsigned char tp_vp ;      	// Validity Period, 1 octet (For relative VPF only!)
	 int           tp_udl;		// User Data Lengh
	 unsigned char tp_ud[160];	// User Data
	 int           nb;          	// Number of octets in the final tp_ud
	 int  length;               	// Number of octets in the final TPDU
	 } sms_submit;

typedef struct // Incoming TPDU
{
	 unsigned char tp_mt;	     	// The first octet (MTI, etc.)
	 unsigned char tp_oa[12];	// Origin Address (max 12 octets)
	 char oa_txt[22];          	// Origin Address converted ASCII text
	 unsigned char tp_pid;  	// Protocol ID
	 unsigned char tp_dcs;		// Data Coding Scheme
	 unsigned char tp_sct[15];  	// Service Centre Time Stamp (ASCII)
	 int  tp_udl;			// User Data Length
	 unsigned char tp_ud[141]; 	// User Data
	 int  length;              	// Number of octets in the TPDU
	 char txt[161];            	// Decoded message text (ASCII)
	 int  nb;                  	// Number of octets in the decoded text
	 } sms_deliver;

// Structure definition of the address fields in the TPDU
typedef struct
	{
	char len;          		// Address length field
	char type;         		// Address type field
	char value[20];    		// Adrress value (normally subscriber number),
										 // max 20 digits
	} tp_adr;
#define SMS_MR_ERR  		-1
#define SMS_DA_ERR  		-2
#define SMS_TXT_ERR 		-3
#define SMS_OK        		 0


